import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { useEffect, useState } from 'react';
import { render } from 'react-dom';
import { ThemeProvider } from '@mui/material/styles';
import muiLightTheme from '../theme/muiLightTheme';
import Jupyter from '../../jupyter/Jupyter';
import { useJupyter } from '../../jupyter/JupyterContext';
import CellLumino from '../../widgets/cell/CellLumino';
import CellControl from './../controls/CellControl';
import CommandsLumino from '../../widgets/commands/CommandsLumino';
import CommandsControl from '../controls/CommandsControl';
import ConsoleLumino from '../../widgets/console/ConsoleLumino';
import ConsoleControl from '../controls/ConsoleControl';
// import DialogLumino from './../examples/dialog/DialogLumino';
import DialogControl from '../controls/DialogControl';
import FileBrowser from '../../widgets/filebrowser/FileBrowser';
import FileBrowserLumino from '../../widgets/filebrowser/FileBrowserLumino';
import FileBrowserControl from '../controls/FileBrowserControl';
import NotebookLumino from '../../widgets/notebook/NotebookLumino';
import NotebookControl from '../controls/NotebookControl';
import OutputLumino from '../../widgets/outputs/OutputLumino';
import OutputControl from '../controls/OutputControl';
import Kernel from '../../services/kernel/Kernel';
import SettingsLumino from '../../widgets/settings/SettingsLumino';
import SettingsControl from '../controls/SettingsControl';
import SimpleLumino from '../examples/lumino/LuminoExample';
import SimpleControl from '../controls/SimpleControl';
import TerminalLumino from '../../widgets/terminal/TerminalLumino';
import TerminalControl from '../controls/TerminalControl';
/**
 * The source to be shown in the examples.
 */
const source = `from IPython.display import display
for i in range(3):
    display('😃 String {} added to the DOM in separated DIV.'.format(i))

import numpy as np
import matplotlib.pyplot as plt
x1 = np.linspace(0.0, 5.0)
x2 = np.linspace(0.0, 2.0)
y1 = np.cos(2 * np.pi * x1) * np.exp(-x1)
y2 = np.cos(2 * np.pi * x2)
fig, (ax1, ax2) = plt.subplots(2, 1)
fig.suptitle('A tale of 2 subplots')
ax1.plot(x1, y1, 'o-')
ax1.set_ylabel('Damped oscillation')
ax2.plot(x2, y2, '.-')
ax2.set_xlabel('time (s)')
ax2.set_ylabel('Undamped')
plt.show()`;
/**
 * A simple example for the Jupyter React.
 */
const Example = () => {
    const { baseUrl, wsUrl } = useJupyter();
    const [kernel,] = useState(new Kernel({ baseUrl, wsUrl }));
    useEffect(() => { window.scrollTo(0, 0); }, []);
    return _jsxs(_Fragment, { children: [_jsx(OutputControl, {}, void 0),
            _jsx(OutputLumino, { showEditor: true, autoRun: false, kernel: kernel, code: "print('Hello Datalayer 👍')" }, void 0),
            _jsx(OutputLumino, { showEditor: true, autoRun: true, kernel: kernel, code: source }, void 0),
            _jsx(OutputLumino, { showEditor: false, autoRun: true, kernel: kernel, code: "print('=> Hello Datalayer again... I am the output of an non-shown editor 👍 <=')" }, void 0),
            _jsx(CellControl, {}, void 0),
            _jsx(CellLumino, { source: source }, void 0),
            _jsx(CommandsControl, {}, void 0),
            _jsx(CommandsLumino, {}, void 0),
            _jsx(ConsoleControl, {}, void 0),
            _jsx(ConsoleLumino, {}, void 0),
            _jsx(DialogControl, {}, void 0),
            _jsx(FileBrowserControl, {}, void 0),
            _jsx(FileBrowser, {}, void 0),
            _jsx(FileBrowserLumino, {}, void 0),
            _jsx(NotebookControl, {}, void 0),
            _jsx(NotebookLumino, { path: 'ping.ipynb', ipywidgets: 'classic' }, void 0),
            _jsx(SettingsControl, {}, void 0),
            _jsx(SettingsLumino, {}, void 0),
            _jsx(SimpleControl, {}, void 0),
            _jsx(SimpleLumino, {}, void 0),
            _jsx(TerminalControl, {}, void 0),
            _jsx(TerminalLumino, {}, void 0)] }, void 0);
};
const div = document.createElement('div');
document.body.appendChild(div);
render(_jsx(ThemeProvider, Object.assign({ theme: muiLightTheme }, { children: _jsx(Jupyter, Object.assign({ collaborative: true, terminals: true }, { children: _jsx(Example, {}, void 0) }), void 0) }), void 0), div);
//# sourceMappingURL=All.bootstrap.js.map