var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { ServerConnection, KernelManager, SessionManager } from '@jupyterlab/services';
import { UUID } from '@lumino/coreutils';
/*
const headers = new Headers({
//  'Cookie': 'Test',
  'X-Datalayer': 'Datalayer',
});
*/
class Kernel {
    //  private _useStorage: boolean;
    //  private _storageKey: string;
    //  private _storageExpire: number;
    constructor(options = {}) {
        this._serverSettings = ServerConnection.makeSettings({
            baseUrl: options.baseUrl || (location.protocol + '//' + location.host + "/api/jupyter"),
            wsUrl: options.wsUrl || (location.protocol.replace('http', 'ws') + '//' + location.host + "/api/jupyter"),
            appendToken: true,
            init: {
                credentials: "include",
                mode: 'cors',
                //        headers: headers,
            }
        });
        this._kernelType = options.kernelType || 'python3';
        this._eventName = options.eventName || 'dla-jupyter-output';
        //    this._useStorage = options.useStorage == undefined ? true : options.useStorage;
        //    this._storageKey = options.storageKey || 'dla-jupyter-output';
        //    this._storageExpire = options.storageExpire || 60;
    }
    getJupyterKernel() {
        if (this._kernelPromise) {
            return this._kernelPromise;
        }
        /*
        if (this._useStorage && typeof window !== 'undefined') {
          const stored = window.localStorage.getItem(this._storageKey);
          if (stored) {
            const { settings, timestamp } = JSON.parse(stored);
            if (timestamp && new Date().getTime() < timestamp) {
              this._kernelPromise = this.requestKernel(settings);
              return this._kernelPromise;
            }
            window.localStorage.removeItem(this._storageKey);
          }
        }
        */
        this._kernelPromise = this.requestKernel();
        return this._kernelPromise;
    }
    requestKernel() {
        return __awaiter(this, void 0, void 0, function* () {
            /*
            if (this._useStorage && typeof window !== 'undefined') {
              const timestamp = new Date().getTime() + this._storageExpire * 60 * 1000;
              const json = JSON.stringify({this._serverSettings, timestamp});
              window.localStorage.setItem(this._storageKey, json);
            }
            */
            const kernelManager = new KernelManager({
                serverSettings: this._serverSettings,
                standby: 'never',
            });
            const sessionManager = new SessionManager({
                serverSettings: this._serverSettings,
                kernelManager,
                standby: 'never',
            });
            yield sessionManager.ready;
            const kernelId = UUID.uuid4();
            const session = yield sessionManager.startNew({
                path: kernelId,
                name: kernelId,
                type: this._kernelType,
            });
            yield session.kernel.info;
            this.event('ready', session.kernel.info);
            return session.kernel;
        });
    }
    event(status, data) {
        const ev = new CustomEvent(this._eventName, { detail: { status, data } });
        document.dispatchEvent(ev);
    }
}
export default Kernel;
//# sourceMappingURL=Kernel.js.map