import actionCreatorFactory from "typescript-fsa";
import { useSelector } from "react-redux";
import { combineEpics } from "redux-observable";
import { map, ignoreElements, tap } from "rxjs/operators";
import { ofAction } from "@datalayer/typescript-fsa-redux-observable";
import { reducerWithInitialState } from "typescript-fsa-reducers";
export const cellInitialState = {
    source: '',
    outputsCount: -1,
    kernelAvailable: false,
};
/* Selectors */
export const selectCell = () => useSelector((state) => {
    if (state.cell) {
        return state.cell;
    }
    return cellInitialState;
});
/* Actions */
export var ActionType;
(function (ActionType) {
    ActionType["SOURCE"] = "cell/SOURCE";
    ActionType["OUTPUTS_COUNT"] = "cell/OUTPUTS_COUNT";
    ActionType["EXECUTE"] = "cell/EXECUTE";
    ActionType["UPDATE"] = "cell/UPDATE";
})(ActionType || (ActionType = {}));
const actionCreator = actionCreatorFactory('jupyterReact');
export const cellActions = {
    source: actionCreator.async(ActionType.SOURCE),
    outputsCount: actionCreator.async(ActionType.OUTPUTS_COUNT),
    execute: actionCreator.async(ActionType.EXECUTE),
    update: actionCreator.async(ActionType.UPDATE),
};
/* Epics */
export const cellEpics = (cellAdapter) => {
    const sourceEpic = action$ => action$.pipe(ofAction(cellActions.source.started), map(action => {
        return cellActions.source.done({
            params: action.payload,
            result: action.payload
        });
    }));
    const outputsCountEpic = action$ => action$.pipe(ofAction(cellActions.outputsCount.started), map(action => {
        return cellActions.outputsCount.done({
            params: action.payload,
            result: action.payload
        });
    }));
    const executeEpic = action$ => action$.pipe(ofAction(cellActions.execute.started), tap(action => cellAdapter.execute()), ignoreElements());
    const updateEpic = action$ => action$.pipe(ofAction(cellActions.update.started), map(action => {
        return cellActions.update.done({
            params: action.payload,
            result: action.payload
        });
    }));
    /*
      const loggingEpic: Epic<
        AnyAction,
        AnyAction,
        ICellState
      > = action$ =>
        action$
          .pipe(
            ofAction(cellActions.outputs.started),
      //      tap(action => console.log(action.type)),
            ignoreElements()
          );
    */
    return combineEpics(sourceEpic, outputsCountEpic, executeEpic, updateEpic);
};
/* Reducers */
export const cellReducer = reducerWithInitialState(cellInitialState)
    .case(cellActions.source.done, (state, success) => {
    return Object.assign(Object.assign({}, state), { source: success.result });
})
    .case(cellActions.update.done, (state, payload) => (Object.assign(Object.assign({}, state), payload.result)))
    .case(cellActions.outputsCount.done, (state, success) => {
    return Object.assign(Object.assign({}, state), { outputsCount: success.result });
});
//# sourceMappingURL=CellState.js.map